@@ -39,8 +39,13 @@ void do_help_mouse(int x,int y,int mbutton)
 {
 	if (x>MAIN_WIN_X && x<MAIN_WIN_X+MAIN_WIN_W
 		&& y>MAIN_WIN_Y && y<MAIN_WIN_Y+MAIN_WIN_H)
+	{
 		do_help_buttons(x,y);
-	else if (x>HELP_BUTTON_X && x<HELP_BUTTON_X+HELP_BUTTON_W
+		return;
+	}
+	if (block_help_exit)
+		return;
+	if (x>HELP_BUTTON_X && x<HELP_BUTTON_X+HELP_BUTTON_W
 		&& y>HELP_BUTTON_Y && y<HELP_BUTTON_Y+HELP_BUTTON_H
 		&& help_history_count>1)
 	{
@@ -58,8 +63,8 @@ void do_help_mouse(int x,int y,int mbutton)
                         do_mouse_other_buttons(x,y,mbutton);
 	}
 //		cs_mouse_handler(mbutton,0,0);
-	else if (block_help_exit==0)
-	{
+//	else if (block_help_exit==0)
+//	{
 		help_flag=0;
 #ifdef USE_EXPANDED_FONT
 		Fgl_setwritemode(WRITEMODE_OVERWRITE | FONT_EXPANDED);
@@ -67,14 +72,21 @@ void do_help_mouse(int x,int y,int mbutton)
 		Fgl_setfontcolors(TEXT_BG_COLOUR,TEXT_FG_COLOUR);
 #endif
 		refresh_main_screen();
-	}
+//	}
 }
 
 void draw_help_page(char *helppage)
 {
-	char s[256],ss[50];
-	int i;
+	char *s,*ss;
+	int i,y;
 	FILE *inf;
+
+	i=strlen(helppage);
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(helppath)+i+64))==0)
+		malloc_failure();
+	if ((ss=(char *)malloc(i+64))==0)
+		malloc_failure();
+
 	if (strncmp(helppage,"return",6)==0)
 	{
 		sscanf(&(helppage[6]),"%d",&help_return_val);
@@ -180,6 +192,15 @@ void draw_help_page(char *helppage)
 				case(9): load_flag=1; break;
                         }
                 }
+		else if (help_history_count>0 &&
+			strcmp(help_button_history[help_history_count-1]
+			,"ask-dir.hlp")==0)
+		{
+			if (help_return_val==1
+				|| help_return_val==-2)
+				do_error("User exited");
+//				make_dir_ok_flag=1;
+		}
 		block_help_exit=0;
 		return;
 	}
@@ -218,6 +239,17 @@ continue_with_help:
 		parse_helpline(s);
 	}
 	fclose(inf);
+	if (strncmp(helppage,"ask-dir.hlp",11)==0)
+	{
+		parse_helpline("tcolour 0 255");
+		y=100;
+		for (i=0;i<askdir_lines;i++)
+		{
+			sprintf(s,"text -1 %d %s",y,askdir_path[i]);
+			parse_helpline(s);
+			y+=14;
+		}
+	}
 continue_with_help2:
 	if (help_history_count>0)
 	{
