@@ -27,7 +27,7 @@
 
 
 //                       ********   NOTE    VERSION
-#define VERSION 109
+#define VERSION 110
 //                       ********   NOTE    VERSION
 
 #define MIN_LOAD_VERSION 97
@@ -1026,6 +1026,7 @@ extern void ore_reserve_setup(void);
 extern void setup_river(void);
 extern void setup_river2(int,int,int);
 extern void check_savedir(void);
+extern void make_savedir(void);
 extern void draw_save_dir(int);
 extern void input_save_filename(char *);
 extern int verify_city(char *);
@@ -1064,6 +1065,7 @@ extern int sust_fire_cover(void);
 extern void check_endian(void);
 extern void eswap32(int *);
 extern void eswap16(unsigned short *);
+extern void malloc_failure(void);
 
 // type init functions
 // *******************
