@@ -59,6 +59,10 @@ main(int argc,char *argv[])
 	int q;
 	vga_init();
 #endif
+
+//printf("uid=%d euid=%d\n",getuid(),geteuid());
+//exit(0);
+	make_dir_ok_flag=1;
 	main_screen_originx=1;
 	main_screen_originy=1;
 	given_scene[0]=0;
@@ -68,7 +72,7 @@ main(int argc,char *argv[])
 	quit_flag=load_flag=save_flag=cheat_flag=monument_bul_flag
 		=river_bul_flag=no_init_help=0;
 	kmouse_val=8;
-	check_for_old_save_dir();
+// 	check_for_old_save_dir();
 	check_savedir();
 	init_path_strings();
 #ifndef CS_PROFILE
@@ -189,7 +193,10 @@ void test(void)
 	{
 		block_help_exit=1;
 		help_flag=1;
-		activate_help("opening.hlp");
+		if (make_dir_ok_flag)
+			activate_help("ask-dir.hlp");
+		else
+			activate_help("opening.hlp");
 	}
 	selected_type=CST_TRACK_LR;
 	selected_type_cost=GROUP_TRACK_COST;
@@ -465,6 +472,8 @@ this_is_not_really_here:  // :)
 		}
 		if (help_flag!=0)
 			lc_usleep(1);
+		if (make_dir_ok_flag)
+			make_savedir();    // sorry a bit crude :(
 	}
 	while ( /* q!='q' && q!='Q' && */ real_quit_flag==0 );
 }
@@ -549,32 +558,39 @@ void do_save_city()
 
 void remove_scene(char *cname)
 {
-	char s[200];
-	if (strlen(cname) < 2)   //  Thanks to
+	char *s;
+	int l;
+	if ((l=strlen(cname)) < 2)   //  Thanks to
 		return;          //  Chris J. Kiick
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+	if ((s=(char *)malloc(lc_save_dir_len+l+16))==0)
+		malloc_failure();
+        strcpy(s,lc_save_dir);
         strcat(s,"/");
         strcat(s,cname);
 	remove(s);
+	free(s);
 }
 
 void save_city(char *cname)
 {
-	char s[200],s2[200],s3[200];
-	int x,y,z,q,n;
+	char *s,*s2,*s3;
+	int x,y,z,q,n,l;
 	FILE *ofile;
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+
+	if ((l=strlen(cname)) < 2)
+		return;
+	if ((s=(char *)malloc(lc_save_dir_len+l+16))==0)
+		malloc_failure();
+	if ((s2=(char *)malloc(lc_save_dir_len+l+32))==0)
+		malloc_failure();
+	if ((s3=(char *)malloc((lc_save_dir_len+l)*2+32))==0)
+		malloc_failure();
+
+        strcpy(s,lc_save_dir);
 	strcat(s,"/");
 	strcpy(s2,s);
         strcat(s2,"tmp-save");
         strcat(s,cname);
-//	strcpy(s2,"gzip -c -9 > ");
-//	strcpy(s2,"gzip -c > ");
-//	strcat(s2,s);
 	if ((ofile=fopen(s2,"w"))==NULL)
 	{
 		printf("Save file <%s> - ",s2);
@@ -725,7 +741,7 @@ void save_city(char *cname)
 	fclose(ofile);
 	strcpy(s3,"gzip -f ");
 	strcat(s3,s2);
-printf("(%s)\n",s3);
+//printf("(%s)\n",s3);
 	if (system(s3)!=0)
 		do_error("gzip failed while in save_city");
 	strcat(s2,".gz");
@@ -733,10 +749,13 @@ printf("(%s)\n",s3);
 	strcat(s3,s2);
 	strcat(s3," ");
 	strcat(s3,s);
-printf("(%s)\n",s3);
+//printf("(%s)\n",s3);
 	if (system(s3)!=0)
 		do_error("mv failed while in save_city");
 	prog_box("",100);
+	free(s);
+	free(s2);
+	free(s3);
 }
 
 void do_load_city(void)
@@ -815,15 +834,19 @@ void do_load_city(void)
 
 void load_op_city(char *s)
 {
-	char s1[256],s2[256];
+	char *s1,*s2;
+	int l;
+	l=strlen(LIBDIR);
+	if ((s1=(char *)malloc(lc_save_dir_len+l+64))==0)
+		malloc_failure();
+	if ((s2=(char *)malloc(lc_save_dir_len+64))==0)
+		malloc_failure();
 	strcpy(s1,"cp ");
         strcat(s1,LIBDIR);
         strcat(s1,"/opening/");
 	strcat(s1,s);
 	strcat(s1," ");
-        strcpy(s2,getenv("HOME"));
-        strcat(s2,"/");
-        strcat(s2,LC_SAVE_DIR);
+        strcpy(s2,lc_save_dir);
         strcat(s2,"/");
 	strcat(s2,s);
 	strcat(s1,s2);
@@ -840,25 +863,27 @@ void load_op_city(char *s)
         suppress_ok_buttons=1;
         update_select_buttons();
         suppress_ok_buttons=0;
+	free(s1);
+	free(s2);
 }
 
 void load_city(char *cname)
 {
-	char s[200],s2[200],s3[100];
-        int x,y,z,q,n,v,i;
+	char *s,*s2,*s3;
+        int x,y,z,q,n,v,i,l;
         FILE *ofile;
-//	if (cname[1]=='_')
-//	{
-        	strcpy(s,getenv("HOME"));
-        	strcat(s,"/");
-        	strcat(s,LC_SAVE_DIR);
-		strcat(s,"/");
-//	}
-//	else
-//	{
-//		strcpy(s,LIBDIR);
-//		strcat(s,"/opening/");
-//	}
+
+        if ((l=strlen(cname)) < 2)
+                return;
+        if ((s=(char *)malloc(lc_save_dir_len+l+16+1024))==0)
+                malloc_failure();
+        if ((s2=(char *)malloc(lc_save_dir_len+l+32))==0)
+                malloc_failure();
+        if ((s3=(char *)malloc((lc_save_dir_len+l)*2+32))==0)
+                malloc_failure();
+
+	strcpy(s,lc_save_dir);
+	strcat(s,"/");
 	strcpy(s2,s);
 	strcat(s2,"tmp-load");
 	strcat(s,cname);
@@ -886,6 +911,9 @@ void load_city(char *cname)
 	{
 		ok_dial_box("too-old.mes",BAD,0L);
 		fclose(ofile);
+		free(s3);
+		free(s2);
+		free(s);
 		return;
 	}
 	unprint_cheat();
@@ -1035,10 +1063,10 @@ pbar_money_olddiff=0;
 	fscanf(ofile,"%d",&x); // for backwards compatibility.
 // 10 dummy strings, for missed out things, have been put in save.
 // Input from this point uses them.
-	fscanf(ofile,"%s",given_scene);
+	fscanf(ofile,"%128s",given_scene);
 	if (strncmp(given_scene,"dummy",5)==0 || strlen(given_scene)<3)
 		given_scene[0]=0;
-	fscanf(ofile,"%s",s);
+	fscanf(ofile,"%128s",s);
 	if (strncmp(given_scene,"dummy",5)!=0)
 		sscanf(s,"%d",&highest_tech_level);
 	else
@@ -1089,6 +1117,9 @@ pbar_money_olddiff=0;
 
 	print_total_money();
 	reset_animation_times();
+	free(s3);
+	free(s2);
+	free(s);
 }
 
 void reset_animation_times(void)
@@ -1255,53 +1286,77 @@ void setup_river2(int x,int y,int d)
 
 void check_savedir(void)
 {
-	char s[100],c;
+	int i=0,j,k,r,l;
 	DIR *dp;
-	strcpy(lc_save_dir,LC_SAVE_DIR);
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,lc_save_dir);
-        if ((dp=opendir(s))==NULL)
-        {
-		printf(
-"\n  LinCity is about to create a directory in which to save your games.\n");
-		printf("\n It is called %s\n",lc_save_dir);
-		printf("       Is this OK?  (Y/n):");
-		c=getchar();
-		if (c=='n' || c=='N')
-		{
-			printf(
-" Sorry, can't continue without this directory\n");
-			exit(0);
-		}
+	lc_save_dir_len=strlen(getenv("HOME"))+strlen(LC_SAVE_DIR)+1;
+	if ((lc_save_dir=(char *)malloc(lc_save_dir_len+16))==0)
+		malloc_failure();
 
-                mkdir(s,0755);
+	strcpy(lc_save_dir,getenv("HOME"));
+	strcat(lc_save_dir,"/");
+	strcat(lc_save_dir,LC_SAVE_DIR);
+ 
+
+        if ((dp=opendir(lc_save_dir))==NULL)
+	{
+		l=lc_save_dir_len;
+		if (l>160)
+		{
+			i=l-160;
+			l=160;
+		}
+		askdir_lines=l/40+((l%40) ? 1 : 0);
+		r=l/askdir_lines+((l%askdir_lines) ? 1 : 0);
+		for (j=0;j<askdir_lines;j++)
+		{
+			if ((askdir_path[j]=(char *)malloc(r+1))==0)
+				malloc_failure();
+			for (k=0;k<r;k++,i++)
+				*(askdir_path[j]+k)=lc_save_dir[i];
+			*(askdir_path[j]+k)=0;
+		}
+		return;
+	}
+	closedir(dp);
+	make_dir_ok_flag=0; // don't load the ask-dir
+}
+
+void make_savedir(void)
+{
+	DIR *dp;
+	if (make_dir_ok_flag==0)
+		return; 
+        mkdir(lc_save_dir,0755);
 #ifndef __EMX__
-		chown(s,getuid(),getgid());
+	chown(lc_save_dir,getuid(),getgid());
 #endif
-                if ((dp=opendir(s))==NULL)
-                {
-                        printf("Couldn't create the save directory %s\n",s);
-                        return;
-                }
+        if ((dp=opendir(lc_save_dir))==NULL)
+        {
+// change this to a screen message.
+                printf("Couldn't create the save directory %s\n",lc_save_dir);
+                exit(1);
         }
 	closedir(dp);
+	make_dir_ok_flag=0;
 }
 
 
 void draw_save_dir(int bg_colour)
 {
-	char s[100],s2[200];
+	char *s,s2[200];
 	int i,j,l;
 	DIR *dp;
 	struct dirent *ep;
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)+64))==0)
+		malloc_failure();		
 
-	strcpy(s,getenv("HOME"));
-	strcat(s,"/");
-	strcat(s,LC_SAVE_DIR);
+	strcpy(s,lc_save_dir);
+//	strcat(s,"/");
+//	strcat(s,LC_SAVE_DIR);
 	if ((dp=opendir(s))==NULL)
 	{
 			printf("Couldn't find the save directory %s\n",s);
+			free(s);
 			return;
 	}
 	for (i=1;i<10;i++)
@@ -1338,6 +1393,7 @@ void draw_save_dir(int bg_colour)
 	}
 	closedir(dp);
 	Fgl_setfontcolors(bg_colour,TEXT_FG_COLOUR);
+	free(s);
 }
 
 void input_save_filename(char *s)
@@ -1413,22 +1469,31 @@ void input_save_filename(char *s)
 
 int verify_city(char *cname)
 {
-        char s[200],s2[200];
+        char *s,*s2;
         int v;
-	v=0;
         FILE *ofile;
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+	v=0;
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)+64))==0)
+		malloc_failure();
+	if ((s2=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)+128))==0)
+		malloc_failure();
+
+        strcpy(s,lc_save_dir);
         strcat(s,"/");
         strcat(s,cname);
         strcpy(s2,"gzip -d -c ");
         strcat(s2,s);
 	strcat(s2," 2> /dev/null");
         if ((ofile=popen(s2,"r"))==NULL)
+	{
+		free(s2);
+		free(s);
 		return(0);
+	}
         fscanf(ofile,"%d",&v);
 	pclose(ofile);
+	free(s2);
+	free(s);
         if (v!=VERSION)
                 return(0);
 	return(1);
@@ -1808,9 +1873,15 @@ void order_select_buttons(void)
 
 void lincityrc(void)
 {
-	char s[100],s1[100];
+	char *s,*s1;
 	int i;
 	FILE *rc;
+
+	if ((s=(char *)malloc(lc_save_dir_len+64))==0)
+		malloc_failure();
+	if ((s1=(char *)malloc(strlen(message_path)+64))==0)
+		malloc_failure();
+
 	strcpy(s,getenv("HOME"));
 	strcat(s,"/");
 	strcat(s,".lincityrc");
@@ -1855,8 +1926,11 @@ void lincityrc(void)
 			lc_mouse_type=i;
 	}
 	fclose(rc);
+	free(s1);
+	free(s);
 }
 
+/*
 void check_for_old_save_dir(void)
 {
 	char s[100],s1[100],command[100],c;
@@ -1911,7 +1985,7 @@ printf("     3. Forget the whole thing and exit LinCity.\n");
 		} while (1);
 	}
 }
-
+*/
 
 int count_groups(int g)
 {
@@ -1940,11 +2014,14 @@ void count_all_groups(void)
 
 int compile_results(void)
 {
-	char s[256];
+	char *s;
 	FILE *outf;
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)
+			+strlen(RESULTS_FILENAME)+64))==0)
+		malloc_failure();
+
+        strcpy(s,lc_save_dir);
         strcat(s,"/");
         strcat(s,RESULTS_FILENAME);
 
@@ -1952,6 +2029,7 @@ int compile_results(void)
 	if ((outf=fopen(s,"w"))==0)
 	{
 		printf("Unable to open %s\n",RESULTS_FILENAME);
+		free(s);
 		return(0);
 	}
 	if (cheat_flag)
@@ -2010,19 +2088,22 @@ int compile_results(void)
 		,group_count[GROUP_HEALTH],group_count[GROUP_TIP]
 		,group_count[GROUP_SHANTY]);
 	fclose(outf);
+	free(s);
 	return(1);
 }
 
 
 void print_results(void)
 {
-	char s[256];
+	char *s;
 	if (compile_results()==0)
 		return;
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)
+			+strlen(RESULTS_FILENAME)+64))==0)
+		malloc_failure();
+
 	strcpy(s,"cat ");
-        strcat(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+        strcat(s,lc_save_dir);
         strcat(s,"/");
         strcat(s,RESULTS_FILENAME);
 	printf("\n");
@@ -2030,6 +2111,7 @@ void print_results(void)
 	printf("\n");
 }
 
+/*
 void mail_results(void)
 {
         char s[256];
@@ -2043,16 +2125,18 @@ void mail_results(void)
         strcat(s,RESULTS_FILENAME);
         system(s);
 }
-
+*/
 
 void window_results(void)
 {
-	char s[256];
+	char *s;
 	if (compile_results()==0)
 		return;
-        strcpy(s,getenv("HOME"));
-        strcat(s,"/");
-        strcat(s,LC_SAVE_DIR);
+	if ((s=(char *)malloc(lc_save_dir_len+strlen(LC_SAVE_DIR)
+			+strlen(RESULTS_FILENAME)+64))==0)
+		malloc_failure();
+
+        strcpy(s,lc_save_dir);
         strcat(s,"/");
         strcat(s,RESULTS_FILENAME);
 	ok_dial_box(s,RESULTS,"Game statistics");
@@ -2212,6 +2296,7 @@ void lc_usleep(unsigned long t)
         select(1, NULL, NULL, NULL, &timeout);
 }
 
+#ifdef 0
 void dump_tcore(void)
 {
 #ifdef ALLOW_TCORE_DUMP
@@ -2304,6 +2389,7 @@ void dump_tcore(void)
 	prog_box("",100);
 #endif
 }
+#endif 0
 
 #ifdef MP_SANITY_CHECK
 void sanity_check(void)
@@ -2527,3 +2613,8 @@ void eswap16(unsigned short *i)
 	*cs=c1;
 }
 
+void malloc_failure()
+{
+	printf("Out of memory: malloc failure\n");
+	exit(1);
+}
