@@ -4,6 +4,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <strings.h>
+#ifdef SCO
+#include <string.h>
+#endif
 
 #ifdef LC_X11
 #include <X11/Xlib.h>
@@ -54,8 +57,6 @@ void mouse_setup(void)
 void cs_mouse_repeat(void)
 {
 // called from main loop when cs_mouse_button==MOUSE_LEFTBUTTON
-//	if (market_cb_flag)
-//		return;
 	if (cs_mouse_button_repeat<=real_time)
 		cs_mouse_handler(cs_mouse_button,0,0);
 // cs_mouse_button_repeat zeroed by handler
@@ -65,8 +66,6 @@ void cs_mouse_repeat(void)
 void cs_mouse_handler(int button, int dx, int dy)
 {
 	int x,y;
-// printf("b=%d dx=%d dy=%d ox=%d oy=%d\n"
-// ,button,dx,dy,cs_mouse_x,cs_mouse_y);
 	x=cs_mouse_x;
 	y=cs_mouse_y;
 #ifndef LC_X11
@@ -115,12 +114,10 @@ void cs_mouse_handler(int button, int dx, int dy)
 // Left button has auto repeat.
 	if ((cs_mouse_button==0 
 		|| cs_mouse_button_repeat<=real_time)
-//		&& (button==MOUSE_LEFTBUTTON || button==MOUSE_RIGHTBUTTON)
 		&& button!=0
 		&& cs_mouse_button_delay==0)
 	{
 		cs_mouse_button_repeat=real_time+500;
-//printf("Mouse button pressed at %d %d\n",x,y);
 		if (market_cb_flag)
 			do_market_cb_mouse(x,y);
 		else if (port_cb_flag)
@@ -458,11 +455,6 @@ void do_select_button(int button,int mbutton)
 		if (mbutton==MOUSE_RIGHTBUTTON)
 			return;
 	}
-//	if (select_button_tflag[button]==0)
-//	{
-//		ok_dial_box("not_enough_tech.mes",BAD,0L);
-//		return;
-//	}
 	selected_button=button;
 	unhighlight_select_button(old_selected_button);
 	highlight_select_button(button);
@@ -715,8 +707,6 @@ void do_mouse_main_win(int x,int y,int button)
 		mappoint[x][y].int_2=tech_level;
 		let_one_through=1;
 	}
-//	else if (main_types[selected_type].group==GROUP_RESIDENCE)
-//		mappoint[x][y].population=2;
 	else if (main_types[selected_type].group==GROUP_RECYCLE
 		|| main_types[selected_type].group==GROUP_POWER_SOURCE_COAL)
 		mappoint[x][y].int_4=tech_level;
@@ -731,10 +721,6 @@ void do_mouse_main_win(int x,int y,int button)
 		let_one_through=1;
 	if (main_types[selected_type].size==2)
 	{
-//		if (mappointtype[x+1][y]!=0
-//			|| mappointtype[x][y+1]!=0
-//			|| mappointtype[x+1][y+1]!=0)
-//			return;
 		mappointtype[x+1][y]=CST_USED;
 		set_mappoint_ints(x,y,x+1,y);
 		mappointtype[x][y+1]=CST_USED;
@@ -744,15 +730,6 @@ void do_mouse_main_win(int x,int y,int button)
 	}
 	else if (main_types[selected_type].size==3)
 	{
-//		if (mappointtype[x+1][y]!=0
-//			|| mappointtype[x+2][y]!=0
-//			|| mappointtype[x+1][y+1]!=0
-//			|| mappointtype[x+2][y+1]!=0
-//			|| mappointtype[x+1][y+2]!=0
-//			|| mappointtype[x+2][y+2]!=0
-//			|| mappointtype[x][y+1]!=0
-//			|| mappointtype[x][y+2]!=0)
-//			return;
 		mappointtype[x+1][y]=CST_USED;
 		set_mappoint_ints(x,y,x+1,y);
 		mappointtype[x+2][y]=CST_USED;
@@ -772,23 +749,6 @@ void do_mouse_main_win(int x,int y,int button)
 	}
         else if (main_types[selected_type].size==4)
         {
-//                if (mappointtype[x+1][y]!=0
-//                        || mappointtype[x+2][y]!=0
-//                        || mappointtype[x+1][y+1]!=0
-//                        || mappointtype[x+2][y+1]!=0
-//                        || mappointtype[x+1][y+2]!=0
-//                        || mappointtype[x+2][y+2]!=0
-//                        || mappointtype[x][y+1]!=0
-//                        || mappointtype[x][y+2]!=0
-
-//			|| mappointtype[x+3][y]!=0
-//			|| mappointtype[x+3][y+1]!=0
-//			|| mappointtype[x+3][y+2]!=0
-//			|| mappointtype[x+3][y+3]!=0
-//			|| mappointtype[x][y+3]!=0
-//			|| mappointtype[x+1][y+3]!=0
-//			|| mappointtype[x+2][y+3]!=0)
-//			return;
                 mappointtype[x+1][y]=CST_USED;
 		set_mappoint_ints(x,y,x+1,y);
                 mappointtype[x+2][y]=CST_USED;
@@ -1125,7 +1085,11 @@ void do_mouse_other_buttons(int x,int y,int button)
 // this is the results (stats) button
 	else if (x>RESULTSBUT_X && x<RESULTSBUT_X+RESULTSBUT_W
 		&& y>RESULTSBUT_Y && y<RESULTSBUT_Y+RESULTSBUT_H)
+	{
+		if (button==MOUSE_RIGHTBUTTON)
+			return;
 		window_results();
+	}
 
 // this is the overwrite transport button button
         else if (x>TOVERBUT_X && x<TOVERBUT_X+TOVERBUT_W
@@ -1406,8 +1370,6 @@ void bulldoze_area(int x,int y)
 			ok_dial_box("nobull-tip.mes",BAD,0L);
 			return;
 		}
-//printf("Bull cost %d g=%d sbut[g]=%d\n"
-//	,select_button_bul_cost[sbut[g]],g,sbut[g]);
 	        total_money-=select_button_bul_cost[sbut[g]];
 	        print_total_money();
 	}
@@ -1508,7 +1470,6 @@ void clear_mappoint(int fill,int x,int y)
 void do_market_cb_mouse(int x,int y)
 {
 	hide_mouse();
-//	if (x>=MARKET_CB_X+2*8 && x<=MARKET_CB_X+4*8) // buy col
 	if (x>=MARKET_CB_X+2*8 && x<=MARKET_CB_X+16*8) // buy col
 	{
 		if (y>=MARKET_CB_Y+3*8+4 && y<=MARKET_CB_Y+5*8+4) // food
@@ -1572,7 +1533,6 @@ void do_market_cb_mouse(int x,int y)
 		                        ,16,16,unchecked_box_graphic);
 		}
 	}
-//	else if (x>=MARKET_CB_X+14*8 && x<=MARKET_CB_X+16*8) // sell col
 	if (x>=MARKET_CB_X+2*8 && x<=MARKET_CB_X+16*8) // sell col
 	{
 		if (y>=MARKET_CB_Y+3*8+4 && y<=MARKET_CB_Y+5*8+4) // food
@@ -2063,7 +2023,6 @@ void choose_residence(void)
 void do_multi_transport(int x, int y, int action)
 {
 	int i;
-printf("do_mt x=%d y=%d action=%d mt_flag=%d\n",x,y,action,mt_flag);
 	switch(action)
 	{
 		case (MT_START):
@@ -2104,7 +2063,6 @@ int mt_draw(int x,int y)
 {
 	static flag=0;
 	static int tlinex[30],tliney[30]; // only need 25
-// printf("mt_draw x=%d y=%d\n",x,y);
 	int i,j,dx,dy;
 	if (flag==0)
 	{
@@ -2117,6 +2075,15 @@ int mt_draw(int x,int y)
 	}
 	if (x<0)  // we must clear the tline array without undrawing
 	{
+        	i=0;
+        	while (tlinex[i]>=0)
+        	{
+             	if (main_types[selected_type].group==GROUP_TRACK
+                 	||main_types[selected_type].group==GROUP_ROAD
+                 	||main_types[selected_type].group==GROUP_RAIL)
+               	mappoint[tlinex[i]][tliney[i]].flags|=FLAG_IS_TRANSPORT;
+             	i++;
+           	}
 		for (i=0;i<27;i++)
 			tlinex[i]=-1;
 		return(0);
@@ -2128,7 +2095,6 @@ int mt_draw(int x,int y)
 		{
 			mappointtype[tlinex[i]][tliney[i]]=CST_GREEN;
 			tlinex[i]=-1;
-//			tliney[i]=-1;
 		}
 		else
 			break;
@@ -2232,7 +2198,6 @@ int mt_draw(int x,int y)
 	i=0;
 	while (tlinex[i]>=0)
 	{
-// printf("dt %d %d    ",tlinex[i],tliney[i]);
 		mappointtype[tlinex[i]][tliney[i]]=selected_type;
 		i++;
 	}
