@@ -15,6 +15,9 @@
 #endif
 #include <math.h>
 #include <strings.h>
+#ifdef SCO
+#include <string.h>
+#endif
 #include <unistd.h>
 #include "lctypes.h"
 #include "lin-city.h"
@@ -25,7 +28,6 @@ void mappoint_stats(int x,int y,int button)
 {
 	static xx=0,yy=0,oldbut=0;
 	char s[100];
-//	int i;
 
 	if (x<0 || y<0)
 	{
@@ -51,17 +53,6 @@ void mappoint_stats(int x,int y,int button)
 				clicked_port_cb(xx,yy);
 				return;
 			}
-//			else if (main_types[mappointtype[xx][yy]].group
-//				&& mappointtype[xx][yy]==CST_ROCKET_FLOWN)
-//			{
-//				if (yn_dial_box("ROCKET LAUNCH"
-//		,"You can launch the rocket now or wait until later."
-//		,"If you wait, it costs you *only* money to keep the"
-//		,"rocket ready.    Launch?")!=0)
-//					launch_rocket(xx,yy);
-//				else
-//					return;
-//			}
 		}
 		xx=x;
 		yy=y;
