@@ -6,7 +6,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <strings.h>
+#ifdef SCO
 #include <string.h>
+#endif
 #include <sys/types.h>
 #include <unistd.h>
 //#ifndef SUNOS
