@@ -15,6 +15,9 @@
 #include <vgamouse.h>
 #endif
 #include <strings.h>
+#ifdef SCO
+#include <string.h>
+#endif
 #include "lctypes.h"
 #include "lin-city.h"
 #include "typeinit.h"
@@ -160,10 +163,6 @@ void init_types(void)
 		=load_graphic(CST_SUBSTATION_RG_G);
 
 	strcpy(type_string[GROUP_RESIDENCE],"Residential");
-//        main_types[CST_RESIDENCE_0].group=GROUP_RESIDENCE;
-//        main_types[CST_RESIDENCE_0].size=3;
-//        main_types[CST_RESIDENCE_0].graphic=load_graphic(CST_RESIDENCE_0_G);
-
         main_types[CST_RESIDENCE_LL].group=GROUP_RESIDENCE;
         main_types[CST_RESIDENCE_LL].size=3;
         main_types[CST_RESIDENCE_LL].graphic=load_graphic(CST_RESIDENCE_LL_G);
@@ -1277,12 +1276,6 @@ void init_types(void)
         main_types[CST_SHANTY].graphic
                 =load_graphic(CST_SHANTY_G);
 
-/*
-	main_types[].group=;
-        main_types[].size=1;
-        main_types[].graphic=load_graphic(_G);
-*/
-
 	fire_chance[GROUP_BARE]=GROUP_BARE_FIREC;
 	fire_chance[GROUP_POWER_LINE]=GROUP_POWER_LINE_FIREC;
 	fire_chance[GROUP_POWER_SOURCE]=GROUP_POWER_SOURCE_FIREC;
